@@ -7,7 +7,7 @@ from .requests.espn_requests import EspnFantasyRequests
 
 class BaseLeague(ABC):
     '''Creates a League instance for Public/Private ESPN league'''
-    def __init__(self, league_id: int, year: int, sport: str, espn_s2=None, swid=None, username=None, password=None, debug=False):
+    def __init__(self, league_id: int, year: int, sport: str, espn_s2=None, swid=None, debug=False):
         self.logger = Logger(name=f'{sport} league', debug=debug)
         self.league_id = league_id
         self.year = year
@@ -22,8 +22,6 @@ class BaseLeague(ABC):
                 'SWID': swid
             }
         self.espn_request = EspnFantasyRequests(sport=sport, year=year, league_id=league_id, cookies=cookies, logger=self.logger)
-        if username and password:
-            self.espn_request.authentication(username, password)
 
     def __repr__(self):
         return 'League(%s, %s)' % (self.league_id, self.year, )
@@ -34,6 +32,7 @@ class BaseLeague(ABC):
         self.currentMatchupPeriod = data['status']['currentMatchupPeriod']
         self.scoringPeriodId = data['scoringPeriodId']
         self.firstScoringPeriod = data['status']['firstScoringPeriod']
+        self.finalScoringPeriod = data['status']['finalScoringPeriod']
         if self.year < 2018:
             self.current_week = data['scoringPeriodId']
         else:
@@ -89,6 +88,17 @@ class BaseLeague(ABC):
                 game_data = pro_game[str(scoringPeriodId)][0]
                 pro_team_schedule[team['id']] = (game_data['homeProTeamId'], game_data['date'])  if team['id'] == game_data['awayProTeamId'] else (game_data['awayProTeamId'], game_data['date'])
         return pro_team_schedule
+    
+    def _get_all_pro_schedule(self):
+        data = self.espn_request.get_pro_schedule()
+
+        pro_teams = data['settings']['proTeams']
+        pro_team_schedule = {}
+
+        for team in pro_teams:
+            pro_game = team.get('proGamesByScoringPeriod', {})
+            pro_team_schedule[team['id']] = pro_game
+        return pro_team_schedule
 
     def standings(self) -> List:
         standings = sorted(self.teams, key=lambda x: x.final_standing if x.final_standing != 0 else x.standing, reverse=False)
